# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pytest_zeebe/engine/engine_control_grpc/pytest_zeebe_engine_control.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIpytest_zeebe/engine/engine_control_grpc/pytest_zeebe_engine_control.proto\x12\x0f\x65ngine_protocol\"\x14\n\x12StartEngineRequest\"\x15\n\x13StartEngineResponse\"\x13\n\x11StopEngineRequest\"\x14\n\x12StopEngineResponse\"\x14\n\x12ResetEngineRequest\"\x15\n\x13ResetEngineResponse\"+\n\x13IncreaseTimeRequest\x12\x14\n\x0cmilliseconds\x18\x01 \x01(\x05\"\x16\n\x14IncreaseTimeResponse\"*\n\x17WaitForIdleStateRequest\x12\x0f\n\x07timeout\x18\x01 \x01(\x03\"\x1a\n\x18WaitForIdleStateResponse\"*\n\x17WaitForBusyStateRequest\x12\x0f\n\x07timeout\x18\x01 \x01(\x03\"\x1a\n\x18WaitForBusyStateResponse\"\x13\n\x11GetRecordsRequest\"$\n\x0eRecordResponse\x12\x12\n\nrecordJson\x18\x01 \x01(\t2\x9e\x05\n\rEngineControl\x12X\n\x0bStartEngine\x12#.engine_protocol.StartEngineRequest\x1a$.engine_protocol.StartEngineResponse\x12U\n\nStopEngine\x12\".engine_protocol.StopEngineRequest\x1a#.engine_protocol.StopEngineResponse\x12X\n\x0bResetEngine\x12#.engine_protocol.ResetEngineRequest\x1a$.engine_protocol.ResetEngineResponse\x12[\n\x0cIncreaseTime\x12$.engine_protocol.IncreaseTimeRequest\x1a%.engine_protocol.IncreaseTimeResponse\x12g\n\x10WaitForIdleState\x12(.engine_protocol.WaitForIdleStateRequest\x1a).engine_protocol.WaitForIdleStateResponse\x12g\n\x10WaitForBusyState\x12(.engine_protocol.WaitForBusyStateRequest\x1a).engine_protocol.WaitForBusyStateResponse\x12S\n\nGetRecords\x12\".engine_protocol.GetRecordsRequest\x1a\x1f.engine_protocol.RecordResponse0\x01\x42\x31\n-io.camunda.zeebe.process.test.engine.protocolP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pytest_zeebe.engine.engine_control_grpc.pytest_zeebe_engine_control_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n-io.camunda.zeebe.process.test.engine.protocolP\000'
  _globals['_STARTENGINEREQUEST']._serialized_start=94
  _globals['_STARTENGINEREQUEST']._serialized_end=114
  _globals['_STARTENGINERESPONSE']._serialized_start=116
  _globals['_STARTENGINERESPONSE']._serialized_end=137
  _globals['_STOPENGINEREQUEST']._serialized_start=139
  _globals['_STOPENGINEREQUEST']._serialized_end=158
  _globals['_STOPENGINERESPONSE']._serialized_start=160
  _globals['_STOPENGINERESPONSE']._serialized_end=180
  _globals['_RESETENGINEREQUEST']._serialized_start=182
  _globals['_RESETENGINEREQUEST']._serialized_end=202
  _globals['_RESETENGINERESPONSE']._serialized_start=204
  _globals['_RESETENGINERESPONSE']._serialized_end=225
  _globals['_INCREASETIMEREQUEST']._serialized_start=227
  _globals['_INCREASETIMEREQUEST']._serialized_end=270
  _globals['_INCREASETIMERESPONSE']._serialized_start=272
  _globals['_INCREASETIMERESPONSE']._serialized_end=294
  _globals['_WAITFORIDLESTATEREQUEST']._serialized_start=296
  _globals['_WAITFORIDLESTATEREQUEST']._serialized_end=338
  _globals['_WAITFORIDLESTATERESPONSE']._serialized_start=340
  _globals['_WAITFORIDLESTATERESPONSE']._serialized_end=366
  _globals['_WAITFORBUSYSTATEREQUEST']._serialized_start=368
  _globals['_WAITFORBUSYSTATEREQUEST']._serialized_end=410
  _globals['_WAITFORBUSYSTATERESPONSE']._serialized_start=412
  _globals['_WAITFORBUSYSTATERESPONSE']._serialized_end=438
  _globals['_GETRECORDSREQUEST']._serialized_start=440
  _globals['_GETRECORDSREQUEST']._serialized_end=459
  _globals['_RECORDRESPONSE']._serialized_start=461
  _globals['_RECORDRESPONSE']._serialized_end=497
  _globals['_ENGINECONTROL']._serialized_start=500
  _globals['_ENGINECONTROL']._serialized_end=1170
# @@protoc_insertion_point(module_scope)
